Carl Meyer <https://github.com/carljm>
Aymeric Augustin <https://github.com/aaugustin>
Anssi Kääriäinen <https://github.com/akaariai>
Andreas Pelme <https://github.com/pelme>
Marek Malek <https://github.com/marekmalek>
Niels Sandholt Busch <https://github.com/nsb>
